// types/games/turtlesoup.ts

/**
 * 海龟汤游戏状态
 */
export enum TurtleSoupGameStatus {
  CREATED = 'created',      // 已创建
  WAITING = 'waiting',      // 等待开始
  ACTIVE = 'active',        // 进行中
  COMPLETED = 'completed',  // 已完成
  ABANDONED = 'abandoned'   // 已放弃
}

/**
 * 海龟汤游戏难度
 */
export enum TurtleSoupDifficulty {
  EASY = 'easy',
  MEDIUM = 'medium',
  HARD = 'hard'
}

/**
 * 海龟汤主题类型
 */
export enum TurtleSoupThemeType {
  BASIC = 'basic',          // 基础主题（免费）
  PREMIUM = 'premium'       // 特色主题（付费）
}

/**
 * 海龟汤问题答案类型
 */
export enum TurtleSoupAnswerType {
  YES = 'yes',              // 是
  NO = 'no',                // 否
  IRRELEVANT = 'irrelevant' // 不重要
}

/**
 * 游戏提示结构
 */
export interface TurtleSoupHint {
  id: string;              // 提示ID
  content: string;         // 提示内容
  revealed: boolean;       // 是否已公开
  revealedAt?: number;     // 公开时间戳
}

/**
 * 海龟汤问题
 */
export interface TurtleSoupQuestion {
  id: string;                     // 问题ID
  content: string;                // 问题内容
  answer?: TurtleSoupAnswerType;  // 回答类型：是/否/不重要
  askedBy: string;                // 提问者ID
  askedByName: string;            // 提问者名称
  timestamp: number;              // 提问时间戳
  answered: boolean;              // 是否已回答
  answeredAt?: number;            // 回答时间戳
}

/**
 * 游戏主题
 */
export interface TurtleSoupTheme {
  id: string;                     // 主题ID
  name: string;                   // 主题名称
  description: string;            // 主题描述
  type: TurtleSoupThemeType;      // 主题类型
  price?: number;                 // 价格（如果是付费主题）
  isNew?: boolean;                // 是否为新主题
  isLocked?: boolean;             // 是否锁定（需要购买）
}

/**
 * 游戏题目
 */
export interface TurtleSoupPuzzle {
  id: string;                     // 题目ID
  title: string;                  // 题目标题
  description: string;            // 题目描述
  difficulty: TurtleSoupDifficulty; // 题目难度
  averageDuration: number;        // 平均完成时间（分钟）
  price?: number;                  // 价格
  isNew?: boolean;                // 是否为新题目
  isLocked?: boolean;             // 是否锁定（需要购买）
}

/**
 * 游戏设置
 */
export interface TurtleSoupGameSettings {
  themeId: string;                // 选择的主题ID
  puzzleId: string;               // 选择的题目ID
  difficulty: TurtleSoupDifficulty; // 游戏难度
  maxPlayers: number;             // 最大玩家数
  isPrivate: boolean;             // 是否为私人游戏
  password?: string;              // 房间密码
}

/**
 * 海龟汤游戏 - 主持人视图
 */
export interface TurtleSoupGameHostView {
  id: string;                     // 游戏ID
  roomId: string;                 // 房间ID
  title: string;                  // 游戏标题
  roomCode: string;               // 房间代码
  description: string;            // 游戏描述/故事
  solution: string;               // 解决方案（只有主持人可见）
  hints: TurtleSoupHint[];        // 提示列表
  questions: TurtleSoupQuestion[]; // 问题列表
  status: TurtleSoupGameStatus;   // 游戏状态
  createTime: number;             // 创建时间戳
  startTime?: number;             // 开始时间戳
  currentTime?: number;           // 当前时间戳
  duration?: number;              // 已进行时长（分钟）
  hostId: string;                 // 主持人ID
  hostName: string;               // 主持人名称
  players: {                      // 玩家列表
    id: string;                   // 玩家ID
    name: string;                 // 玩家名称
    avatar?: string;              // 头像
    joinedAt: number;             // 加入时间戳
    questionCount: number;        // 提问次数
  }[];
  settings: TurtleSoupGameSettings; // 游戏设置
  playerCount: number;            // 当前玩家数
  progress: number;               // 解谜进度（百分比，主持人估计）
}

/**
 * 海龟汤游戏 - 玩家视图
 */
export interface TurtleSoupGamePlayerView {
  id: string;                     // 游戏ID
  roomId: string;                 // 房间ID
  title: string;                  // 游戏标题
  description: string;            // 游戏描述/故事
  revealedHints: {                // 已公开的提示
    id: string;                   // 提示ID
    content: string;              // 提示内容
    revealedAt: number;           // 公开时间戳
  }[];
  myQuestions: TurtleSoupQuestion[]; // 我的问题
  allQuestions: {                 // 所有已回答的问题
    id: string;
    content: string;
    askedByName: string;
    answer: TurtleSoupAnswerType;
    timestamp: number;
  }[];
  status: TurtleSoupGameStatus;   // 游戏状态
  startTime?: number;             // 开始时间戳
  currentTime?: number;           // 当前时间戳
  duration?: number;              // 已进行时长（分钟）
  hostId: string;                 // 主持人ID
  hostName: string;               // 主持人名称
  progress: number;               // 解谜进度（百分比）
  difficulty: TurtleSoupDifficulty; // 游戏难度
  otherPlayers: {                 // 其他玩家列表
    id: string;
    name: string;
    avatar?: string;
  }[];
}

/**
 * 海龟汤游戏结果
 */
export interface TurtleSoupGameResult {
  gameId: string;                 // 游戏ID
  solved: boolean;                // 是否解决
  solvedBy?: string;              // 解决者ID
  solvedByName?: string;          // 解决者名称
  solution?: string;              // 提交的解答
  duration: number;               // 游戏时长(分钟)
  questionCount: number;          // 总提问次数
  hintsRevealed: number;          // 使用的提示数
  completionTime: number;         // 完成时间戳
  playerCount: number;            // 参与玩家数
}